@@ -141,6 +141,18 @@ void set_ecuid(char *ecuid)
     }
 }
 
+void set_conf(char *file_path)
+{
+    if (file_path != NULL) {
+        memset(local_filename, 0, DLT_MOUNT_PATH_MAX);
+        strncpy(local_filename, file_path, DLT_MOUNT_PATH_MAX);
+        local_filename[DLT_MOUNT_PATH_MAX - 1] = '\0';
+    }
+    else {
+        pr_error("Argument is NULL\n");
+    }
+}
+
 int get_timeout(void)
 {
     return local_timeout;
@@ -325,12 +337,12 @@ static int prepare_headers(DltMessage *msg, uint8_t *header)
     msg->standardheader->mcnt = 0;
 
     /* prepare length information */
-    msg->headersize = (uint32_t) (sizeof(DltStorageHeader) +
-        sizeof(DltStandardHeader) +
-        sizeof(DltExtendedHeader) +
-        DLT_STANDARD_HEADER_EXTRA_SIZE(msg->standardheader->htyp));
+    msg->headersize = (int32_t)(sizeof(DltStorageHeader) +
+                    sizeof(DltStandardHeader) +
+                    sizeof(DltExtendedHeader) +
+                    DLT_STANDARD_HEADER_EXTRA_SIZE(msg->standardheader->htyp));
 
-    len = (uint32_t) (msg->headersize - sizeof(DltStorageHeader) + msg->datasize);
+    len = (uint32_t)(msg->headersize - (int32_t)sizeof(DltStorageHeader) + msg->datasize);
 
     if (len > UINT16_MAX) {
         pr_error("Message header is too long.\n");
@@ -376,7 +388,7 @@ static DltMessage *dlt_control_prepare_message(DltControlMsgBody *data)
     }
 
     /* prepare payload of data */
-    msg->databuffersize = msg->datasize = (uint32_t) data->size;
+    msg->databuffersize = msg->datasize = (int32_t)data->size;
 
     /* Allocate memory for Dlt Message's buffer */
     msg->databuffer = (uint8_t *)calloc(1, data->size);
@@ -420,7 +432,14 @@ static DltMessage *dlt_control_prepare_message(DltControlMsgBody *data)
  */
 static int dlt_control_init_connection(DltClient *client, void *cb)
 {
-    int (*callback)(DltMessage *message, void *data) = cb;
+    union {
+        void *ptr;
+        int (*callback)(DltMessage *message, void *data);
+    } callback_converter;
+    int (*callback)(DltMessage *message, void *data);
+
+    callback_converter.ptr = cb;
+    callback = callback_converter.callback;
 
     if (!cb || !client) {
         pr_error("%s: Invalid parameters\n", __func__);
@@ -612,11 +631,18 @@ int dlt_control_init(int (*response_analyzer)(char *, void *, int),
         return -1;
     }
 
+    union {
+        void *ptr;
+        int (*callback)(DltMessage *message, void *data);
+    } callback_converter;
+
     response_analyzer_cb = response_analyzer;
     set_ecuid(ecuid);
     set_verbosity(verbosity);
+    callback_converter.callback = dlt_control_callback;
 
-    if (dlt_control_init_connection(&g_client, dlt_control_callback) != 0) {
+    /* Initialize DLT connection */
+    if (dlt_control_init_connection(&g_client, callback_converter.ptr) != 0) {
         pr_error("Connection initialization failed\n");
         dlt_client_cleanup(&g_client, get_verbosity());
         return -1;
@@ -651,8 +677,11 @@ int dlt_control_deinit(void)
         close(g_client.receiver.fd);
         g_client.receiver.fd = -1;
     }
-    /* Waiting for thread to complete */
-    pthread_join(daemon_connect_thread, NULL);
+
+    if (pthread_join(daemon_connect_thread, NULL)) {
+        pr_error("Unable to join the thread with ERRNO=%s\n", strerror(errno));
+    }
+
     /* Closing the socket */
     return dlt_client_cleanup(&g_client, get_verbosity());
 }
@@ -827,8 +856,12 @@ DltReturnValue dlt_json_filter_load(DltFilter *filter, const char *filename, int
 
         char app_id[DLT_ID_SIZE];
         char context_id[DLT_ID_SIZE];
+
+        #pragma GCC diagnostic push
+        #pragma GCC diagnostic ignored "-Wstringop-truncation"
         strncpy(app_id, s_app_id, DLT_ID_SIZE);
         strncpy(context_id, s_context_id, DLT_ID_SIZE);
+        #pragma GCC diagnostic pop
 
         dlt_filter_add(filter, app_id, context_id, log_level, payload_min, payload_max, verbose);
 
