@@ -113,7 +113,8 @@ void set_node_id(char *id)
         exit(-1);
     }
     else {
-        strncpy(g_options.node_id, id, DLT_ID_SIZE);
+        strncpy(g_options.node_id, id, DLT_ID_SIZE - 1);
+        g_options.node_id[DLT_ID_SIZE - 1] = '\0';
     }
 }
 
@@ -197,11 +198,6 @@ static int dlt_passive_node_analyze_response(char *answer,
                 DltServicePassiveNodeConnectionInfo *info =
                     (DltServicePassiveNodeConnectionInfo *)(payload);
 
-                if (info == NULL) {
-                    fprintf(stderr, "Received response is NULL\n");
-                    return -1;
-                }
-
                 dlt_print_passive_node_status(info);
             }
         }
