@@ -100,6 +100,9 @@
 /* Default ECU ID, used in storage header and transmitted to client*/
 #define DLT_DAEMON_ECU_ID "ECU1"
 
+/* Default ECU ID Length, used in extended header and transmitted to client*/
+#define DLT_DAEMON_ECU_ID_LEN         4
+
 /* Default baudrate for serial interface */
 #define DLT_DAEMON_SERIAL_DEFAULT_BAUDRATE 115200
 
@@ -108,4 +111,3 @@
 /************************/
 
 #endif /* DLT_DAEMON_CFG_H */
-
