@@ -115,6 +115,24 @@ void dlt_daemon_logstorage_update_application_loglevel(DltDaemon *daemon,
                                                        int dev_num,
                                                        int verbose);
 
+/**
+ * dlt_daemon_logstorage_update_application_loglevel_v2
+ *
+ * DLTv2 Update log level of all running applications with new filter configuration
+ * available due to newly attached DltLogstorage device for DLT version 2.
+ * The log level is only updated when the current application log level is less
+ * than the log level obtained from the storage configuration file.
+ *
+ * @param daemon        Pointer to DLT Daemon structure
+ * @param daemon_local  Pointer to DLT Daemon local structure
+ * @param dev_num       Number of attached DLT Logstorage device
+ * @param verbose       if set to true verbose information is printed out
+ */
+void dlt_daemon_logstorage_update_application_loglevel_v2(DltDaemon *daemon,
+                                                       DltDaemonLocal *daemon_local,
+                                                       int dev_num,
+                                                       int verbose);
+
 /**
  * dlt_daemon_logstorage_write
  *
@@ -130,8 +148,9 @@ void dlt_daemon_logstorage_update_application_loglevel(DltDaemon *daemon,
  * @param size2         message extended data size
  * @param data3         message data buffer
  * @param size3         message data size
+ * @return              0 on success, -1 on error, 1 on disable network routing
  */
-void dlt_daemon_logstorage_write(DltDaemon *daemon,
+int dlt_daemon_logstorage_write(DltDaemon *daemon,
                                  DltDaemonFlags *user_config,
                                  unsigned char *data1,
                                  int size1,
