@@ -14,7 +14,7 @@
  * \author Aditya Paluri <venkataaditya.paluri@in.bosch.com> ADIT 2018
  *
  * \file: dlt_daemon_offline_logstorage_internal.h
- * For further information see http://www.genivi.org/.
+ * For further information see http://www.covesa.org/.
  */
 
 /*******************************************************************************
@@ -61,6 +61,14 @@ DltReturnValue dlt_logstorage_update_all_contexts(DltDaemon *daemon,
                                                   char *ecuid,
                                                   int verbose);
 
+DltReturnValue dlt_logstorage_update_all_contexts_v2(DltDaemon *daemon,
+                                                     DltDaemonLocal *daemon_local,
+                                                     char *id,
+                                                     int curr_log_level,
+                                                     int cmp_flag,
+                                                     char *ecuid,
+                                                     int verbose);
+
 DltReturnValue dlt_logstorage_update_context(DltDaemon *daemon,
                                              DltDaemonLocal *daemon_local,
                                              char *apid,
@@ -75,4 +83,10 @@ DltReturnValue dlt_logstorage_update_context_loglevel(DltDaemon *daemon,
                                                       int curr_log_level,
                                                       int verbose);
 
+DltReturnValue dlt_logstorage_update_context_loglevel_v2(DltDaemon *daemon,
+                                                         DltDaemonLocal *daemon_local,
+                                                         char *key,
+                                                         int curr_log_level,
+                                                         int verbose);
+
 #endif
