@@ -40,6 +40,7 @@
 #include "dlt_gateway_internal.h"
 #include "dlt_config_file_parser.h"
 #include "dlt_common.h"
+#include "dlt_log.h"
 #include "dlt-daemon_cfg.h"
 #include "dlt_daemon_common_cfg.h"
 #include "dlt_daemon_event_handler.h"
@@ -56,15 +57,19 @@
  */
 DLT_STATIC DltReturnValue dlt_gateway_check_ip(DltGatewayConnection *con, char *value)
 {
-    struct sockaddr_in sa;
-    int ret = DLT_RETURN_ERROR;
-
     if ((con == NULL) || (value == NULL)) {
         dlt_vlog(LOG_ERR, "%s: wrong parameter\n", __func__);
         return DLT_RETURN_WRONG_PARAMETER;
     }
 
+    int ret = DLT_RETURN_ERROR;
+#ifdef DLT_USE_IPv6
+    struct sockaddr_in6 sa6;
+    ret = inet_pton(AF_INET6, value, &(sa6.sin6_addr));
+#else
+    struct sockaddr_in sa;
     ret = inet_pton(AF_INET, value, &(sa.sin_addr));
+#endif
 
     /* valid IP address */
     if (ret != 0) {
@@ -313,7 +318,7 @@ DLT_STATIC DltReturnValue dlt_gateway_check_control_messages(DltGatewayConnectio
             return DLT_RETURN_ERROR;
         }
 
-        con->p_control_msgs->id = strtol(token, NULL, 16);
+        con->p_control_msgs->id = (uint32_t)strtol(token, NULL, 16);
         con->p_control_msgs->user_id = DLT_SERVICE_ID_PASSIVE_NODE_CONNECT;
         con->p_control_msgs->type = CONTROL_MESSAGE_ON_STARTUP;
         con->p_control_msgs->req = CONTROL_MESSAGE_NOT_REQUESTED;
@@ -384,7 +389,7 @@ DLT_STATIC DltReturnValue dlt_gateway_check_periodic_control_messages(
         p_token = strtok_r(token, ":", &p_rest);
 
         if ((p_token != NULL) && (strlen(p_token) != 0)) {
-            id = strtol(p_token, NULL, 16);
+            id = (uint32_t)strtol(p_token, NULL, 16);
 
             /* get back to head */
             con->p_control_msgs = head;
@@ -393,7 +398,7 @@ DLT_STATIC DltReturnValue dlt_gateway_check_periodic_control_messages(
             while (con->p_control_msgs != NULL) {
                 if (con->p_control_msgs->id == id) {
                     con->p_control_msgs->type = CONTROL_MESSAGE_BOTH;
-                    con->p_control_msgs->interval = strtol(p_rest, NULL, 10);
+                    con->p_control_msgs->interval = (int)strtol(p_rest, NULL, 10);
 
                     if (con->p_control_msgs->interval <= 0)
                         dlt_vlog(LOG_WARNING,
@@ -430,7 +435,7 @@ DLT_STATIC DltReturnValue dlt_gateway_check_periodic_control_messages(
                 con->p_control_msgs->user_id = DLT_SERVICE_ID_PASSIVE_NODE_CONNECT;
                 con->p_control_msgs->type = CONTROL_MESSAGE_PERIODIC;
                 con->p_control_msgs->req = CONTROL_MESSAGE_NOT_REQUESTED;
-                con->p_control_msgs->interval = strtol(p_rest, NULL, 10);
+                con->p_control_msgs->interval = (int)strtol(p_rest, NULL, 10);
 
                 if (con->p_control_msgs->interval <= 0)
                     dlt_vlog(LOG_WARNING,
@@ -603,9 +608,6 @@ int dlt_gateway_store_connection(DltGateway *gateway,
         i++;
     }
 
-    if (&(gateway->connections[i]) == NULL)
-        return DLT_RETURN_ERROR;
-
     /* store values */
     gateway->connections[i].ip_address = strdup(tmp->ip_address);
     gateway->connections[i].ecuid = strdup(tmp->ecuid);
@@ -700,7 +702,7 @@ int dlt_gateway_configure(DltGateway *gateway, char *config_file, int verbose)
         gateway->num_connections = num_sections - 1;
     }
 
-    gateway->connections = calloc(gateway->num_connections,
+    gateway->connections = calloc((size_t)gateway->num_connections,
                                 sizeof(DltGatewayConnection));
 
     if (gateway->connections == NULL) {
@@ -975,11 +977,6 @@ int dlt_gateway_establish_connections(DltGateway *gateway,
         DltGatewayConnection *con = &(gateway->connections[i]);
         DltPassiveControlMessage *control_msg = NULL;
 
-        if (con == NULL) {
-            dlt_log(LOG_CRIT, "Cannot retrieve gateway connection details\n");
-            return DLT_RETURN_ERROR;
-        }
-
         if ((con->status != DLT_GATEWAY_CONNECTED) &&
             (con->trigger != DLT_GATEWAY_ON_DEMAND) &&
             (con->trigger != DLT_GATEWAY_DISABLED)) {
@@ -1174,8 +1171,8 @@ DLT_STATIC DltReturnValue dlt_gateway_parse_get_log_info(DltDaemon *daemon,
             if (dlt_daemon_context_add(daemon,
                                        app.app_id,
                                        con.context_id,
-                                       con.log_level,
-                                       con.trace_status,
+                                       (int8_t)con.log_level,
+                                       (int8_t)con.trace_status,
                                        0,
                                        -1,
                                        con.context_description,
@@ -1355,7 +1352,7 @@ DltReturnValue dlt_gateway_process_passive_node_messages(DltDaemon *daemon,
 
     while (dlt_message_read(&msg,
                             (unsigned char *)receiver->buf,
-                            receiver->bytesRcvd,
+                            (unsigned int)receiver->bytesRcvd,
                             0,
                             verbose) == DLT_MESSAGE_ERROR_OK) {
         DltStandardHeaderExtra *header = (DltStandardHeaderExtra *)
@@ -1427,11 +1424,11 @@ DltReturnValue dlt_gateway_process_passive_node_messages(DltDaemon *daemon,
                                        daemon,
                                        daemon_local,
                                        msg.headerbuffer,
-                                       sizeof(DltStorageHeader),
+                                       (int)sizeof(DltStorageHeader),
                                        msg.headerbuffer + sizeof(DltStorageHeader),
-                                       msg.headersize - sizeof(DltStorageHeader),
+                                       (int)((size_t)msg.headersize - sizeof(DltStorageHeader)),
                                        msg.databuffer,
-                                       msg.datasize,
+                                       (int)((size_t)msg.datasize),
                                        verbose);
         } else { /* otherwise remove this connection and do not connect again */
             dlt_vlog(LOG_WARNING,
@@ -1462,19 +1459,19 @@ DltReturnValue dlt_gateway_process_passive_node_messages(DltDaemon *daemon,
 
         if (msg.found_serialheader) {
             if (dlt_receiver_remove(receiver,
-                                    msg.headersize +
-                                    msg.datasize -
+                                    (int)((size_t)msg.headersize +
+                                    (size_t)msg.datasize -
                                     sizeof(DltStorageHeader) +
-                                    sizeof(dltSerialHeader)) == -1) {
+                                    sizeof(dltSerialHeader))) == -1) {
                 /* Return value ignored */
                 dlt_message_free(&msg, verbose);
                 return DLT_RETURN_ERROR;
             }
         }
         else if (dlt_receiver_remove(receiver,
-                                     msg.headersize +
-                                     msg.datasize -
-                                     sizeof(DltStorageHeader)) == -1) {
+                                     (int)((size_t)msg.headersize +
+                                     (size_t)msg.datasize -
+                                     sizeof(DltStorageHeader))) == -1) {
             /* Return value ignored */
             dlt_message_free(&msg, verbose);
             return DLT_RETURN_ERROR;
@@ -1573,8 +1570,8 @@ int dlt_gateway_forward_control_message(DltGateway *gateway,
     }
 
     if (con->send_serial) { /* send serial header */
-        ret = send(con->client.sock,
-                   (void *)dltSerialHeader,
+        ret = (int)send(con->client.sock,
+                   (const void *)dltSerialHeader,
                    sizeof(dltSerialHeader),
                    0);
 
@@ -1584,9 +1581,9 @@ int dlt_gateway_forward_control_message(DltGateway *gateway,
         }
     }
 
-    ret = send(con->client.sock,
+    ret = (int)send(con->client.sock,
                msg->headerbuffer + sizeof(DltStorageHeader),
-               msg->headersize - sizeof(DltStorageHeader),
+               (size_t)(msg->headersize - (int)sizeof(DltStorageHeader)),
                0);
 
     if (ret == -1) {
@@ -1594,7 +1591,7 @@ int dlt_gateway_forward_control_message(DltGateway *gateway,
         return DLT_RETURN_ERROR;
     }
     else {
-        ret = send(con->client.sock, msg->databuffer, msg->datasize, 0);
+        ret = (int)send(con->client.sock, msg->databuffer, (size_t)msg->datasize, 0);
 
         if (ret == -1) {
             dlt_log(LOG_ERR, "Sending message to passive DLT Daemon failed\n");
@@ -1611,11 +1608,94 @@ int dlt_gateway_forward_control_message(DltGateway *gateway,
     return DLT_RETURN_OK;
 }
 
-int dlt_gateway_process_on_demand_request(DltGateway *gateway,
-                                          DltDaemonLocal *daemon_local,
-                                          char node_id[DLT_ID_SIZE],
-                                          int connection_status,
-                                          int verbose)
+int dlt_gateway_forward_control_message_v2(DltGateway *gateway,
+                                           DltDaemonLocal *daemon_local,
+                                           DltMessageV2 *msg,
+                                           uint8_t eculen,
+                                           char *ecu,
+                                           int verbose)
+{
+    int i = 0;
+    int ret = 0;
+    DltGatewayConnection *con = NULL;
+    uint32_t id_tmp;
+    uint32_t id;
+
+    PRINT_FUNCTION_VERBOSE(verbose);
+
+    if ((gateway == NULL) || (daemon_local == NULL) || (msg == NULL) || (ecu == NULL)) {
+        dlt_vlog(LOG_ERR, "%s: wrong parameter\n", __func__);
+        return DLT_RETURN_WRONG_PARAMETER;
+    }
+
+    for (i = 0; i < gateway->num_connections; i++)
+        if (strncmp(gateway->connections[i].ecuid2,
+                    ecu,
+                    eculen) == 0) {
+            con = &gateway->connections[i];
+            break;
+        }
+
+
+
+    if (con == NULL) {
+        dlt_log(LOG_WARNING, "Unknown passive node identifier\n");
+        return DLT_RETURN_ERROR;
+    }
+
+    if (con->status != DLT_GATEWAY_CONNECTED) {
+        dlt_log(LOG_INFO, "Passive node is not connected\n");
+        return DLT_RETURN_ERROR;
+    }
+
+    if (con->send_serial) { /* send serial header */
+        ret = (int)send(con->client.sock,
+                   (const void *)dltSerialHeader,
+                   sizeof(dltSerialHeader),
+                   0);
+
+        if (ret == -1) {
+            dlt_log(LOG_ERR, "Sending message to passive DLT Daemon failed\n");
+            return DLT_RETURN_ERROR;
+        }
+    }
+
+    //TBD: Review if storage header needs to be sent for v2
+    //TBD: Review msg->storageheadersizev2 or need to calculate size
+    ret = (int)send(con->client.sock,
+               (const void *)(msg->headerbufferv2 + msg->storageheadersizev2),
+               (size_t)(msg->headersizev2 - (int32_t)msg->storageheadersizev2),
+               0);
+
+    if (ret == -1) {
+        dlt_log(LOG_ERR, "Sending message to passive DLT Daemon failed\n");
+        return DLT_RETURN_ERROR;
+    }
+    else {
+        ret = (int)send(con->client.sock, msg->databuffer, (size_t)msg->datasize, 0);
+
+        if (ret == -1) {
+            dlt_log(LOG_ERR, "Sending message to passive DLT Daemon failed\n");
+            return DLT_RETURN_ERROR;
+        }
+    }
+
+    id_tmp = *((uint32_t *)(msg->databuffer));
+    //TBD: Review id extraction for v2
+    id = DLT_ENDIAN_GET_32(msg->baseheaderv2->htyp2, id_tmp);
+
+    //TBD: Review check if dlt_get_service_name_v2 is needed
+    dlt_vlog(LOG_INFO,
+             "Control message forwarded : %s\n",
+             dlt_get_service_name(id));
+    return DLT_RETURN_OK;
+}
+
+DltReturnValue dlt_gateway_process_on_demand_request(DltGateway *gateway,
+                                                     DltDaemonLocal *daemon_local,
+                                                     char *node_id,
+                                                     int conn_status,
+                                                     int verbose)
 {
     int i = 0;
     DltGatewayConnection *con = NULL;
@@ -1640,7 +1720,7 @@ int dlt_gateway_process_on_demand_request(DltGateway *gateway,
         return DLT_RETURN_ERROR;
     }
 
-    if (connection_status == 1) { /* try to connect */
+    if (conn_status == 1) { /* try to connect */
 
         if (con->status != DLT_GATEWAY_CONNECTED) {
             if (dlt_client_connect(&con->client, verbose) == 0) {
@@ -1659,7 +1739,7 @@ int dlt_gateway_process_on_demand_request(DltGateway *gateway,
             dlt_log(LOG_INFO, "Passive node already connected\n");
         }
     }
-    else if (connection_status == 0) /* disconnect*/
+    else if (conn_status == 0) /* disconnect*/
     {
 
         con->status = DLT_GATEWAY_DISCONNECTED;
@@ -1713,10 +1793,10 @@ int dlt_gateway_send_control_message(DltGatewayConnection *con,
     }
 
     if (con->send_serial) { /* send serial header */
-        ret = send(con->client.sock,
-                   (void *)dltSerialHeader,
-                   sizeof(dltSerialHeader),
-                   0);
+        ret = (int)send(con->client.sock,
+                        (const void *)dltSerialHeader,
+                        sizeof(dltSerialHeader),
+                        0);
 
         if (ret == -1) {
             dlt_log(LOG_ERR, "Sending message to passive DLT Daemon failed\n");
@@ -1758,6 +1838,85 @@ int dlt_gateway_send_control_message(DltGatewayConnection *con,
     return DLT_RETURN_OK;
 }
 
+int dlt_gateway_send_control_message_v2(DltGatewayConnection *con,
+                                        DltPassiveControlMessage *control_msg,
+                                        void *data,
+                                        int verbose)
+{
+    int ret = DLT_RETURN_OK;
+
+    PRINT_FUNCTION_VERBOSE(verbose);
+
+    if (con == NULL) {
+        dlt_vlog(LOG_WARNING,
+                 "%s: Invalid parameter given\n",
+                 __func__);
+        return DLT_RETURN_WRONG_PARAMETER;
+    }
+
+    /* no (more) control message to be send */
+    if (control_msg->id == 0)
+        return DLT_RETURN_ERROR;
+
+    /* check sendtime counter and message interval */
+    /* sendtime counter is 0 on startup, otherwise positive value */
+    if ((control_msg->type != CONTROL_MESSAGE_ON_DEMAND) && (con->sendtime_cnt > 0)) {
+        if (control_msg->interval <= 0)
+            return DLT_RETURN_ERROR;
+
+        if ((control_msg->type == CONTROL_MESSAGE_PERIODIC) ||
+            (control_msg->type == CONTROL_MESSAGE_BOTH)) {
+            if ((con->sendtime_cnt - 1) % control_msg->interval != 0)
+                return DLT_RETURN_ERROR;
+        }
+    }
+
+    if (con->send_serial) { /* send serial header */
+        ret = (int)send(con->client.sock,
+                   (const void *)dltSerialHeader,
+                   sizeof(dltSerialHeader),
+                   0);
+
+        if (ret == -1) {
+            dlt_log(LOG_ERR, "Sending message to passive DLT Daemon failed\n");
+            return DLT_RETURN_ERROR;
+        }
+    }
+
+    switch (control_msg->id) {
+    case DLT_SERVICE_ID_GET_LOG_INFO:
+        return dlt_client_get_log_info_v2(&con->client);
+        break;
+    case DLT_SERVICE_ID_GET_DEFAULT_LOG_LEVEL:
+        return dlt_client_get_default_log_level_v2(&con->client);
+        break;
+    case DLT_SERVICE_ID_GET_SOFTWARE_VERSION:
+        return dlt_client_get_software_version_v2(&con->client);
+        break;
+    case DLT_SERVICE_ID_SET_LOG_LEVEL:
+
+        if (data == NULL) {
+            dlt_vlog(LOG_WARNING,
+                     "Insufficient data for %s received. Send control request failed.\n",
+                     dlt_get_service_name(control_msg->id));
+            return DLT_RETURN_ERROR;
+        }
+
+        DltServiceSetLogLevel *req = (DltServiceSetLogLevel *)data;
+        return dlt_client_send_log_level_v2(&con->client,
+                                         req->apid,
+                                         req->ctid,
+                                         req->log_level);
+        break;
+    default:
+        dlt_vlog(LOG_WARNING,
+                 "Cannot forward request: %s.\n",
+                 dlt_get_service_name(control_msg->id));
+    }
+
+    return DLT_RETURN_OK;
+}
+
 DltGatewayConnection *dlt_gateway_get_connection(DltGateway *gateway,
                                                  char *ecu,
                                                  int verbose)
@@ -1783,3 +1942,29 @@ DltGatewayConnection *dlt_gateway_get_connection(DltGateway *gateway,
 
     return con;
 }
+
+DltGatewayConnection *dlt_gateway_get_connection_v2(DltGateway *gateway,
+                                                    char *ecu,
+                                                    int verbose)
+{
+    DltGatewayConnection *con = NULL;
+    int i = 0;
+
+    PRINT_FUNCTION_VERBOSE(verbose);
+
+    if ((gateway == NULL) || (ecu == NULL)) {
+        dlt_vlog(LOG_ERR, "%s: wrong parameter\n", __func__);
+        return con;
+    }
+
+    for (i = 0; i < gateway->num_connections; i++) {
+        con = &gateway->connections[i];
+        //TBD: REVIEW strlen(ecu) usage
+        if (strncmp(con->ecuid2, ecu, strlen(ecu)) == 0)
+            return con;
+    }
+
+    dlt_vlog(LOG_ERR, "%s: No connection found\n", ecu);
+
+    return con;
+}
