@@ -53,7 +53,9 @@
 
 #include <search.h>
 #include <stdbool.h>
+#ifdef DLT_LOGSTORAGE_USE_GZIP
 #include <zlib.h>
+#endif
 #include "dlt_common.h"
 #include "dlt-daemon_cfg.h"
 #include "dlt_config_file_parser.h"
@@ -69,33 +71,29 @@
 
 #define DLT_OFFLINE_LOGSTORAGE_SYNC_CACHES              2 /* sync logstorage caches */
 
-#define DLT_OFFLINE_LOGSTORAGE_MAX_KEY_LEN             15 /* Maximum size for key */
-#define DLT_OFFLINE_LOGSTORAGE_MAX_FILE_NAME_LEN       50 /* Maximum file name length of the log file */
+#define DLT_OFFLINE_LOGSTORAGE_MAX_KEY_LEN         15  /* Maximum size for key */
+#define DLT_OFFLINE_LOGSTORAGE_MAX_FILE_NAME_LEN   100 /* Maximum file name length of the log file including path under mount point */
 
-#define DLT_OFFLINE_LOGSTORAGE_FILE_EXTENSION_LEN       4
 #define DLT_OFFLINE_LOGSTORAGE_GZ_FILE_EXTENSION_LEN    7
 #define DLT_OFFLINE_LOGSTORAGE_INDEX_LEN                3
 #define DLT_OFFLINE_LOGSTORAGE_MAX_INDEX              999
 #define DLT_OFFLINE_LOGSTORAGE_TIMESTAMP_LEN           16
 #define DLT_OFFLINE_LOGSTORAGE_INDEX_OFFSET        (DLT_OFFLINE_LOGSTORAGE_TIMESTAMP_LEN + \
-                                                    DLT_OFFLINE_LOGSTORAGE_FILE_EXTENSION_LEN + \
                                                     DLT_OFFLINE_LOGSTORAGE_INDEX_LEN)
 #define DLT_OFFLINE_LOGSTORAGE_MAX_LOG_FILE_LEN    (DLT_OFFLINE_LOGSTORAGE_MAX_FILE_NAME_LEN + \
                                                     DLT_OFFLINE_LOGSTORAGE_TIMESTAMP_LEN + \
-                                                    DLT_OFFLINE_LOGSTORAGE_INDEX_LEN + \
-                                                    DLT_OFFLINE_LOGSTORAGE_FILE_EXTENSION_LEN + 1)
+                                                    DLT_OFFLINE_LOGSTORAGE_INDEX_LEN + 1)
 
-#define DLT_OFFLINE_LOGSTORAGE_CONFIG_DIR_PATH_LEN 50
 #define DLT_OFFLINE_LOGSTORAGE_CONFIG_FILE_NAME    "dlt_logstorage.conf"
 
 /* +3 because of device number and \0 */
 #define DLT_OFFLINE_LOGSTORAGE_MAX_PATH_LEN (DLT_OFFLINE_LOGSTORAGE_MAX_LOG_FILE_LEN + \
-                                             DLT_OFFLINE_LOGSTORAGE_CONFIG_DIR_PATH_LEN + 3)
+                                             DLT_MOUNT_PATH_MAX + 3)
 
 #define DLT_OFFLINE_LOGSTORAGE_MAX(A, B)   ((A) > (B) ? (A) : (B))
 #define DLT_OFFLINE_LOGSTORAGE_MIN(A, B)   ((A) < (B) ? (A) : (B))
 
-#define DLT_OFFLINE_LOGSTORAGE_MAX_WRITE_ERRORS     5
+#define DLT_OFFLINE_LOGSTORAGE_MAX_ERRORS           5
 #define DLT_OFFLINE_LOGSTORAGE_MAX_KEY_NUM          8
 
 #define DLT_OFFLINE_LOGSTORAGE_CONFIG_SECTION "FILTER"
@@ -115,6 +113,24 @@
 
 #define DLT_OFFLINE_LOGSTORAGE_IS_STRATEGY_SET(S, s) ((S)&(s))
 
+/* Offline Logstorage overwrite strategies */
+#define DLT_LOGSTORAGE_OVERWRITE_ERROR          -1 /* error case */
+#define DLT_LOGSTORAGE_OVERWRITE_UNSET           0 /* strategy not set */
+#define DLT_LOGSTORAGE_OVERWRITE_DISCARD_OLD     1 /* default, discard old */
+#define DLT_LOGSTORAGE_OVERWRITE_DISCARD_NEW    (1 << 1) /* discard new */
+
+/* Offline Logstorage disable network routing */
+#define DLT_LOGSTORAGE_DISABLE_NW_ERROR         -1 /* error case */
+#define DLT_LOGSTORAGE_DISABLE_NW_UNSET          0 /* not set */
+#define DLT_LOGSTORAGE_DISABLE_NW_OFF            1 /* default, enable network routing */
+#define DLT_LOGSTORAGE_DISABLE_NW_ON            (1 << 1) /* disable network routing */
+
+/* Offline Logstorage disable network routing */
+#define DLT_LOGSTORAGE_GZIP_ERROR               -1 /* error case */
+#define DLT_LOGSTORAGE_GZIP_UNSET                0 /* not set */
+#define DLT_LOGSTORAGE_GZIP_OFF 1                  /* default, no compression */
+#define DLT_LOGSTORAGE_GZIP_ON (1 << 1)            /* enable gzip compression */
+
 /* logstorage max cache */
 extern unsigned int g_logstorage_cache_max;
 /* current logstorage cache size */
@@ -135,6 +151,7 @@ typedef struct
     char logfile_delimiter;             /* Choice of delimiter */
     unsigned int logfile_maxcounter;    /* Maximum file index counter */
     unsigned int logfile_counteridxlen; /* File index counter length */
+    int logfile_optional_counter;       /* Don't append counter for num_files=1 */
 } DltLogStorageUserConfig;
 
 typedef struct DltLogStorageFileList
@@ -162,6 +179,8 @@ struct DltLogStorageFilterConfig
     /* filter section */
     char *apids;                    /* Application IDs configured for filter */
     char *ctids;                    /* Context IDs configured for filter */
+    char *excluded_apids;           /* Excluded Application IDs configured for filter */
+    char *excluded_ctids;           /* Excluded Context IDs configured for filter */
     int log_level;                  /* Log level number configured for filter */
     int reset_log_level;            /* reset Log level to be sent on disconnect */
     char *file_name;                /* File name for log storage configured for filter */
@@ -170,6 +189,8 @@ struct DltLogStorageFilterConfig
     unsigned int file_size;         /* MAX File size of storage file configured for filter */
     unsigned int num_files;         /* MAX number of storage files configured for filters */
     int sync;                       /* Sync strategy */
+    int overwrite;                  /* Overwrite strategy */
+    int skip;                       /* Flag to skip file logging if DISCARD_NEW */
     char *ecuid;                    /* ECU identifier */
     unsigned int gzip_compression;  /* Toggle if log files should be gzip compressed */
     /* callback function for filter configurations */
@@ -196,12 +217,13 @@ struct DltLogStorageFilterConfig
     FILE *log;                      /* current open log file */
     int fd;                         /* The file descriptor for the active log file */
 #ifdef DLT_LOGSTORAGE_USE_GZIP
-    gzFile gzlog;                   /* current open gz log file */
+    gzFile *gzlog;                  /* current open gz log file */
 #endif
     void *cache;                    /* log data cache */
     unsigned int specific_size;     /* cache size used for specific_size sync strategy */
     unsigned int current_write_file_offset;    /* file offset for specific_size sync strategy */
     DltLogStorageFileList *records; /* File name list */
+    int disable_network_routing;    /* Flag to disable routing to network client */
 };
 
 typedef struct DltLogStorageFilterList DltLogStorageFilterList;
@@ -214,6 +236,10 @@ struct DltLogStorageFilterList
     DltLogStorageFilterList *next;    /* Pointer to next */
 };
 
+typedef enum {
+    DLT_LOGSTORAGE_CONFIG_FILE = 0,   /* Use dlt-logstorage.conf file from device */
+} DltLogStorageConfigMode;
+
 typedef struct
 {
     DltLogStorageFilterList *config_list; /* List of all filters */
@@ -222,9 +248,11 @@ typedef struct
     char device_mount_point[DLT_MOUNT_PATH_MAX + 1]; /* Device mount path */
     unsigned int connection_type;      /* Type of connection */
     unsigned int config_status;        /* Status of configuration */
+    int prepare_errors;                /* number of prepare errors */
     int write_errors;                  /* number of write errors */
     DltNewestFileName *newest_file_list; /* List of newest file name */
     int maintain_logstorage_loglevel;  /* Permission to maintain the logstorage loglevel*/
+    DltLogStorageConfigMode config_mode;                   /* Configuration Mechanism */
 } DltLogStorage;
 
 typedef struct {
@@ -247,15 +275,19 @@ typedef struct {
 typedef enum {
     DLT_LOGSTORAGE_FILTER_CONF_LOGAPPNAME = 0,
     DLT_LOGSTORAGE_FILTER_CONF_CONTEXTNAME,
+    DLT_LOGSTORAGE_FILTER_CONF_EXCLUDED_LOGAPPNAME,
+    DLT_LOGSTORAGE_FILTER_CONF_EXCLUDED_CONTEXTNAME,
     DLT_LOGSTORAGE_FILTER_CONF_LOGLEVEL,
     DLT_LOGSTORAGE_FILTER_CONF_RESET_LOGLEVEL,
     DLT_LOGSTORAGE_FILTER_CONF_FILE,
     DLT_LOGSTORAGE_FILTER_CONF_FILESIZE,
     DLT_LOGSTORAGE_FILTER_CONF_NOFILES,
     DLT_LOGSTORAGE_FILTER_CONF_SYNCBEHAVIOR,
+    DLT_LOGSTORAGE_FILTER_CONF_OVERWRITEBEHAVIOR,
     DLT_LOGSTORAGE_FILTER_CONF_ECUID,
     DLT_LOGSTORAGE_FILTER_CONF_SPECIFIC_SIZE,
     DLT_LOGSTORAGE_FILTER_CONF_GZIP_COMPRESSION,
+    DLT_LOGSTORAGE_FILTER_CONF_DISABLE_NETWORK,
     DLT_LOGSTORAGE_FILTER_CONF_COUNT
 } DltLogstorageFilterConfType;
 
@@ -270,7 +302,7 @@ typedef enum {
  * @return               0 on success, -1 on error
  */
 int dlt_logstorage_device_connected(DltLogStorage *handle,
-                                    char *mount_point);
+                                    const char *mount_point);
 
 /**
  * dlt_logstorage_device_disconnected
@@ -330,6 +362,7 @@ int dlt_logstorage_get_loglevel_by_key(DltLogStorage *handle, char *key);
  * @param size2     Size of extended message body
  * @param data3     Data buffer of message body
  * @param size3     Size of message body
+ * @param disable_nw Flag to disable network routing
  * @return          0 on success or write errors < max write errors, -1 on error
  */
 int dlt_logstorage_write(DltLogStorage *handle,
@@ -339,7 +372,8 @@ int dlt_logstorage_write(DltLogStorage *handle,
                          unsigned char *data2,
                          int size2,
                          unsigned char *data3,
-                         int size3);
+                         int size3,
+                         int *disable_nw);
 
 /**
  * dlt_logstorage_sync_caches
