@@ -69,9 +69,9 @@
 #include <sys/stat.h>
 #include <fcntl.h>
 #include <errno.h>
+#include <poll.h>
 
 #include <sys/uio.h> /* writev() */
-#include <sys/time.h> /* timeval */
 
 #include "dlt_user_shared.h"
 #include "dlt_user_shared_cfg.h"
@@ -93,6 +93,23 @@ DltReturnValue dlt_user_set_userheader(DltUserHeader *userheader, uint32_t mtype
     return DLT_RETURN_OK;
 }
 
+DltReturnValue dlt_user_set_userheader_v2(DltUserHeader *userheader, uint32_t mtype)
+{
+    if (userheader == 0)
+        return DLT_RETURN_ERROR;
+
+    if (mtype <= 0)
+        return DLT_RETURN_ERROR;
+
+    userheader->pattern[0] = 'D';
+    userheader->pattern[1] = 'U';
+    userheader->pattern[2] = 'H';
+    userheader->pattern[3] = 2;
+    userheader->message = mtype;
+
+    return DLT_RETURN_OK;
+}
+
 int dlt_user_check_userheader(DltUserHeader *userheader)
 {
     if (userheader == 0)
@@ -101,7 +118,16 @@ int dlt_user_check_userheader(DltUserHeader *userheader)
     return (userheader->pattern[0] == 'D') &&
            (userheader->pattern[1] == 'U') &&
            (userheader->pattern[2] == 'H') &&
-           (userheader->pattern[3] == 1);
+           ((userheader->pattern[3] == 1) || (userheader->pattern[3] == 2));
+}
+
+int dlt_get_version_from_userheader(DltUserHeader *userheader){
+    if (userheader == 0)
+        return -1;
+    
+    int version = userheader->pattern[3];
+    
+    return version;
 }
 
 DltReturnValue dlt_user_log_out2(int handle, void *ptr1, size_t len1, void *ptr2, size_t len2)
@@ -132,16 +158,15 @@ DltReturnValue dlt_user_log_out2_with_timeout(int handle, void *ptr1, size_t len
         /* Invalid handle */
         return DLT_RETURN_ERROR;
 
-    fd_set fds;
-    FD_ZERO(&fds);
-    FD_SET(handle, &fds);
+    struct pollfd pfd;
+    pfd.fd = handle;
+    pfd.events = POLLOUT;
 
-    struct timeval tv = { DLT_WRITEV_TIMEOUT_SEC, DLT_WRITEV_TIMEOUT_USEC };
-    if (select(handle+1, NULL, &fds, NULL, &tv) < 0) {
+    if (poll(&pfd, 1, DLT_WRITEV_TIMEOUT_MS) < 0) {
         return DLT_RETURN_ERROR;
     }
 
-    if (FD_ISSET(handle, &fds)) {
+    if (pfd.revents & POLLOUT) {
         return dlt_user_log_out2(handle, ptr1, len1, ptr2, len2);
     } else {
         return DLT_RETURN_ERROR;
@@ -206,16 +231,15 @@ DltReturnValue dlt_user_log_out3_with_timeout(int handle, void *ptr1, size_t len
         /* Invalid handle */
         return DLT_RETURN_ERROR;
 
-    fd_set fds;
-    FD_ZERO(&fds);
-    FD_SET(handle, &fds);
+    struct pollfd pfd;
+    pfd.fd = handle;
+    pfd.events = POLLOUT;
 
-    struct timeval tv = { DLT_WRITEV_TIMEOUT_SEC, DLT_WRITEV_TIMEOUT_USEC };
-    if (select(handle+1, NULL, &fds, NULL, &tv) < 0) {
+    if (poll(&pfd, 1, DLT_WRITEV_TIMEOUT_MS) < 0) {
         return DLT_RETURN_ERROR;
     }
 
-    if (FD_ISSET(handle, &fds)) {
+    if (pfd.revents & POLLOUT) {
         return dlt_user_log_out3(handle, ptr1, len1, ptr2, len2, ptr3, len3);
     } else {
         return DLT_RETURN_ERROR;
