@@ -243,9 +243,15 @@ TEST(t_dlt_daemon_application_add, normal)
     EXPECT_EQ(0, dlt_daemon_init_user_information(&daemon, &gateway, 0, 0));
     EXPECT_EQ(DLT_RETURN_OK, strncmp(daemon.ecuid, daemon.user_list[0].ecu, DLT_ID_SIZE));
 
-    app = dlt_daemon_application_add(&daemon, (char *)apid, pid, (char *)desc, fd, ecu, 0);
+    char apid_buf[DLT_ID_SIZE+1] = {0};
+    char desc_buf[32] = {0};
+    memcpy(apid_buf, apid, DLT_ID_SIZE);
+    apid_buf[DLT_ID_SIZE] = '\0';
+    strncpy(desc_buf, desc, sizeof(desc_buf)-1);
+    desc_buf[sizeof(desc_buf)-1] = '\0';
+    app = dlt_daemon_application_add(&daemon, apid_buf, pid, desc_buf, fd, ecu, 0);
     /*printf("### APP: APID=%s  DESCR=%s NUMCONTEXT=%i PID=%i USERHANDLE=%i\n", app->apid,app->application_description, app->num_contexts, app->pid, app->user_handle); */
-    EXPECT_STREQ(apid, app->apid);
+    EXPECT_EQ(0, strncmp(apid, app->apid, DLT_ID_SIZE));
     EXPECT_STREQ(desc, app->application_description);
     EXPECT_EQ(pid, app->pid);
     EXPECT_LE(0, dlt_daemon_application_del(&daemon, app, ecu, 0));
@@ -253,11 +259,15 @@ TEST(t_dlt_daemon_application_add, normal)
 
     /* Apid > 4, expected truncate to 4 char or error */
     apid = "TO_LONG";
-    app = dlt_daemon_application_add(&daemon, (char *)apid, pid, (char *)desc, fd, ecu, 0);
+    memcpy(apid_buf, apid, DLT_ID_SIZE);
+    apid_buf[DLT_ID_SIZE] = '\0';
+    strncpy(desc_buf, desc, sizeof(desc_buf)-1);
+    desc_buf[sizeof(desc_buf)-1] = '\0';
+    app = dlt_daemon_application_add(&daemon, apid_buf, pid, desc_buf, fd, ecu, 0);
     char tmp[5];
-    strncpy(tmp, apid, 4);
+    memcpy(tmp, apid, 4);
     tmp[4] = '\0';
-    EXPECT_STREQ(tmp, app->apid);
+    EXPECT_EQ(0, strncmp(tmp, app->apid, DLT_ID_SIZE));
     EXPECT_LE(0, dlt_daemon_application_del(&daemon, app, ecu, 0));
     EXPECT_LE(0, dlt_daemon_applications_clear(&daemon, ecu, 0));
     EXPECT_EQ(0, dlt_daemon_free(&daemon, 0));
@@ -313,14 +323,19 @@ TEST(t_dlt_daemon_application_add, nullpointer)
     const char *desc = "HELLO_TEST";
     int fd = 42;
     char ecu[] = "ECU1";
-
+    char apid_buf[DLT_ID_SIZE+1] = {0};
+    char desc_buf[32] = {0};
     /* NULL-Pointer test */
     EXPECT_EQ((DltDaemonApplication *)0, dlt_daemon_application_add(NULL, NULL, 0, NULL, 0, NULL, 0));
-    EXPECT_EQ((DltDaemonApplication *)0, dlt_daemon_application_add(NULL, NULL, 0, (char *)desc, 0, NULL, 0));
-    EXPECT_EQ((DltDaemonApplication *)0, dlt_daemon_application_add(NULL, (char *)apid, 0, NULL, 0, NULL, 0));
-    EXPECT_EQ((DltDaemonApplication *)0, dlt_daemon_application_add(NULL, (char *)apid, 0, (char *)desc, 0, NULL, 0));
+    strncpy(desc_buf, desc, sizeof(desc_buf)-1);
+    desc_buf[sizeof(desc_buf)-1] = '\0';
+    EXPECT_EQ((DltDaemonApplication *)0, dlt_daemon_application_add(NULL, NULL, 0, desc_buf, 0, NULL, 0));
+    memcpy(apid_buf, apid, DLT_ID_SIZE);
+    apid_buf[DLT_ID_SIZE] = '\0';
+    EXPECT_EQ((DltDaemonApplication *)0, dlt_daemon_application_add(NULL, apid_buf, 0, NULL, 0, NULL, 0));
+    EXPECT_EQ((DltDaemonApplication *)0, dlt_daemon_application_add(NULL, apid_buf, 0, desc_buf, 0, NULL, 0));
     EXPECT_EQ((DltDaemonApplication *)0, dlt_daemon_application_add(&daemon, NULL, 0, NULL, 0, NULL, 0));
-    EXPECT_EQ((DltDaemonApplication *)0, dlt_daemon_application_add(&daemon, NULL, 0, (char *)desc, 0, NULL, 0));
+    EXPECT_EQ((DltDaemonApplication *)0, dlt_daemon_application_add(&daemon, NULL, 0, desc_buf, 0, NULL, 0));
     EXPECT_EQ((DltDaemonApplication *)0, dlt_daemon_application_add(NULL, NULL, 0, NULL, fd, NULL, 0));
     EXPECT_EQ((DltDaemonApplication *)0, dlt_daemon_application_add(NULL, NULL, 0, NULL, 0, ecu, 0));
 }
@@ -349,7 +364,13 @@ TEST(t_dlt_daemon_application_del, normal)
     dlt_set_id(daemon.ecuid, ecu);
     EXPECT_EQ(0, dlt_daemon_init_user_information(&daemon, &gateway, 0, 0));
     EXPECT_EQ(DLT_RETURN_OK, strncmp(daemon.ecuid, daemon.user_list[0].ecu, DLT_ID_SIZE));
-    app = dlt_daemon_application_add(&daemon, (char *)apid, pid, (char *)desc, fd, ecu, 0);
+    char apid_buf[DLT_ID_SIZE+1] = {0};
+    char desc_buf[32] = {0};
+    memcpy(apid_buf, apid, DLT_ID_SIZE);
+    apid_buf[DLT_ID_SIZE] = '\0';
+    strncpy(desc_buf, desc, sizeof(desc_buf)-1);
+    desc_buf[sizeof(desc_buf)-1] = '\0';
+    app = dlt_daemon_application_add(&daemon, apid_buf, pid, desc_buf, fd, ecu, 0);
     EXPECT_LE(0, dlt_daemon_application_del(&daemon, app, ecu, 0));
     EXPECT_LE(0, dlt_daemon_applications_clear(&daemon, ecu, 0));
     EXPECT_EQ(0, dlt_daemon_free(&daemon, 0));
@@ -417,20 +438,33 @@ TEST(t_dlt_daemon_application_find, normal)
     dlt_set_id(daemon.ecuid, ecu);
     EXPECT_EQ(0, dlt_daemon_init_user_information(&daemon, &gateway, 0, 0));
     EXPECT_EQ(DLT_RETURN_OK, strncmp(daemon.ecuid, daemon.user_list[0].ecu, DLT_ID_SIZE));
-    app = dlt_daemon_application_add(&daemon, (char *)apid, pid, (char *)desc, fd, ecu, 0);
-    EXPECT_STREQ(apid, app->apid);
+    char apid_buf[DLT_ID_SIZE+1] = {0};
+    char desc_buf[32] = {0};
+    memcpy(apid_buf, apid, DLT_ID_SIZE);
+    apid_buf[DLT_ID_SIZE] = '\0';
+    strncpy(desc_buf, desc, sizeof(desc_buf)-1);
+    desc_buf[sizeof(desc_buf)-1] = '\0';
+    app = dlt_daemon_application_add(&daemon, apid_buf, pid, desc_buf, fd, ecu, 0);
+    EXPECT_EQ(0, strncmp(apid, app->apid, DLT_ID_SIZE));
     EXPECT_STREQ(desc, app->application_description);
     EXPECT_EQ(pid, app->pid);
     EXPECT_LE(0, dlt_daemon_application_del(&daemon, app, ecu, 0));
     EXPECT_LE(0, dlt_daemon_applications_clear(&daemon, ecu, 0));
 
     /* Application doesn't exist, expect NULL */
-    EXPECT_EQ((DltDaemonApplication *)0, dlt_daemon_application_find(&daemon, ecu, (char *)apid, 0));
+    EXPECT_EQ((DltDaemonApplication *)0, dlt_daemon_application_find(&daemon, ecu, apid_buf, 0));
 
     /* Use a different apid, expect NULL */
-    app = dlt_daemon_application_add(&daemon, (char *)apid, pid, (char *)desc, fd, ecu, 0);
-    EXPECT_LE((DltDaemonApplication *)0, dlt_daemon_application_find(&daemon, ecu, (char *)apid, 0));
-    EXPECT_EQ((DltDaemonApplication *)0, dlt_daemon_application_find(&daemon, ecu, (char *)"NEXI", 0));
+    memcpy(apid_buf, apid, DLT_ID_SIZE);
+    apid_buf[DLT_ID_SIZE] = '\0';
+    strncpy(desc_buf, desc, sizeof(desc_buf)-1);
+    desc_buf[sizeof(desc_buf)-1] = '\0';
+    app = dlt_daemon_application_add(&daemon, apid_buf, pid, desc_buf, fd, ecu, 0);
+    EXPECT_LE((DltDaemonApplication *)0, dlt_daemon_application_find(&daemon, ecu, apid_buf, 0));
+    char nexi[DLT_ID_SIZE+1] = {0};
+    memcpy(nexi, "NEXI", DLT_ID_SIZE);
+    nexi[DLT_ID_SIZE] = '\0';
+    EXPECT_EQ((DltDaemonApplication *)0, dlt_daemon_application_find(&daemon, ecu, nexi, 0));
     EXPECT_LE(0, dlt_daemon_application_del(&daemon, app, ecu, 0));
     EXPECT_LE(0, dlt_daemon_applications_clear(&daemon, ecu, 0));
     EXPECT_EQ(0, dlt_daemon_free(&daemon, 0));
@@ -460,7 +494,10 @@ TEST(t_dlt_daemon_application_find, nullpointer)
 
     /* NULL-Pointer, expected NULL */
     EXPECT_EQ((DltDaemonApplication *)0, dlt_daemon_application_find(NULL, NULL, NULL, 0));
-    EXPECT_EQ((DltDaemonApplication *)0, dlt_daemon_application_find(NULL, (char *)apid, NULL, 0));
+    char apid_buf[DLT_ID_SIZE+1] = {0};
+    memcpy(apid_buf, apid, DLT_ID_SIZE);
+    apid_buf[DLT_ID_SIZE] = '\0';
+    EXPECT_EQ((DltDaemonApplication *)0, dlt_daemon_application_find(NULL, apid_buf, NULL, 0));
     EXPECT_EQ((DltDaemonApplication *)0, dlt_daemon_application_find(&daemon, NULL, NULL, 0));
 }
 /* End Method: dlt_daemon_common::dlt_daemon_applikation_find */
@@ -485,9 +522,26 @@ TEST(t_dlt_daemon_applications_clear, normal)
     dlt_set_id(daemon.ecuid, ecu);
     EXPECT_EQ(0, dlt_daemon_init_user_information(&daemon, &gateway, 0, 0));
     EXPECT_EQ(DLT_RETURN_OK, strncmp(daemon.ecuid, daemon.user_list[0].ecu, DLT_ID_SIZE));
+    char apid1_buf[DLT_ID_SIZE+1] = {0};
+    char desc1_buf[32] = {0};
+    memcpy(apid1_buf, "TES1", DLT_ID_SIZE);
+    apid1_buf[DLT_ID_SIZE] = '\0';
+    strncpy(desc1_buf, "Test clear 1", sizeof(desc1_buf)-1);
+    desc1_buf[sizeof(desc1_buf)-1] = '\0';
     EXPECT_LE((DltDaemonApplication *)0,
-              dlt_daemon_application_add(&daemon, (char *)"TES1", pid, (char *)"Test clear 1", fd, ecu, 0));
-    dlt_daemon_application_add(&daemon, (char *)"TES2", pid, (char *)"Test clear 2", fd, ecu, 0);
+              dlt_daemon_application_add(&daemon, apid1_buf, pid, desc1_buf, fd, ecu, 0));
+    memcpy(apid1_buf, "TES1", DLT_ID_SIZE);
+    apid1_buf[DLT_ID_SIZE] = '\0';
+    strncpy(desc1_buf, "Test clear 1", sizeof(desc1_buf)-1);
+    desc1_buf[sizeof(desc1_buf)-1] = '\0';
+    dlt_daemon_application_add(&daemon, apid1_buf, pid, desc1_buf, fd, ecu, 0);
+    char apid2_buf[DLT_ID_SIZE+1] = {0};
+    char desc2_buf[32] = {0};
+    memcpy(apid2_buf, "TES2", DLT_ID_SIZE);
+    apid2_buf[DLT_ID_SIZE] = '\0';
+    strncpy(desc2_buf, "Test clear 2", sizeof(desc2_buf)-1);
+    desc2_buf[sizeof(desc2_buf)-1] = '\0';
+    dlt_daemon_application_add(&daemon, apid2_buf, pid, desc2_buf, fd, ecu, 0);
     EXPECT_LE(0, dlt_daemon_applications_clear(&daemon, ecu, 0));
     EXPECT_EQ(0, dlt_daemon_free(&daemon, 0));
 }
@@ -535,7 +589,13 @@ TEST(t_dlt_daemon_applications_invalidate_fd, normal)
     dlt_set_id(daemon.ecuid, ecu);
     EXPECT_EQ(0, dlt_daemon_init_user_information(&daemon, &gateway, 0, 0));
     EXPECT_EQ(DLT_RETURN_OK, strncmp(daemon.ecuid, daemon.user_list[0].ecu, DLT_ID_SIZE));
-    app = dlt_daemon_application_add(&daemon, (char *)apid, pid, (char *)desc, fd, ecu, 0);
+    char apid_buf[DLT_ID_SIZE+1] = {0};
+    char desc_buf[32] = {0};
+    memcpy(apid_buf, apid, DLT_ID_SIZE);
+    apid_buf[DLT_ID_SIZE] = '\0';
+    strncpy(desc_buf, desc, sizeof(desc_buf)-1);
+    desc_buf[sizeof(desc_buf)-1] = '\0';
+    app = dlt_daemon_application_add(&daemon, apid_buf, pid, desc_buf, fd, ecu, 0);
     EXPECT_LE(0, dlt_daemon_applications_invalidate_fd(&daemon, ecu, app->user_handle, 0));
     EXPECT_LE(0, dlt_daemon_application_del(&daemon, app, ecu, 0));
     EXPECT_LE(0, dlt_daemon_applications_clear(&daemon, ecu, 0));
@@ -591,8 +651,17 @@ TEST(t_dlt_daemon_applications_save, normal)
     dlt_set_id(daemon.ecuid, ecu);
     EXPECT_EQ(0, dlt_daemon_init_user_information(&daemon, &gateway, 0, 0));
     EXPECT_EQ(DLT_RETURN_OK, strncmp(daemon.ecuid, daemon.user_list[0].ecu, DLT_ID_SIZE));
-    app = dlt_daemon_application_add(&daemon, (char *)apid, pid, (char *)desc, fd, ecu, 0);
-    EXPECT_LE(0, dlt_daemon_applications_save(&daemon, (char *)filename, 0));
+    char apid_buf[DLT_ID_SIZE+1] = {0};
+    char desc_buf[32] = {0};
+    memcpy(apid_buf, apid, DLT_ID_SIZE);
+    apid_buf[DLT_ID_SIZE] = '\0';
+    strncpy(desc_buf, desc, sizeof(desc_buf)-1);
+    desc_buf[sizeof(desc_buf)-1] = '\0';
+    app = dlt_daemon_application_add(&daemon, apid_buf, pid, desc_buf, fd, ecu, 0);
+    char filename_buf[256] = {0};
+    strncpy(filename_buf, filename, sizeof(filename_buf)-1);
+    filename_buf[sizeof(filename_buf)-1] = '\0';
+    EXPECT_LE(0, dlt_daemon_applications_save(&daemon, filename_buf, 0));
     EXPECT_LE(0, dlt_daemon_application_del(&daemon, app, ecu, 0));
     EXPECT_LE(0, dlt_daemon_applications_clear(&daemon, ecu, 0));
     EXPECT_EQ(0, dlt_daemon_free(&daemon, 0));
@@ -630,7 +699,10 @@ TEST(t_dlt_daemon_applications_save, nullpointer)
 
     /* NULL-Pointer */
     EXPECT_GE(-1, dlt_daemon_applications_save(NULL, NULL, 0));
-    EXPECT_GE(-1, dlt_daemon_applications_save(NULL, (char *)filename, 0));
+    char filename_buf[256] = {0};
+    strncpy(filename_buf, filename, sizeof(filename_buf)-1);
+    filename_buf[sizeof(filename_buf)-1] = '\0';
+    EXPECT_GE(-1, dlt_daemon_applications_save(NULL, filename_buf, 0));
     EXPECT_GE(-1, dlt_daemon_applications_save(&daemon, NULL, 0));
 }
 /* End Method: dlt_daemon_common::dlt_daemon_applications_save */
@@ -654,7 +726,10 @@ TEST(t_dlt_daemon_applications_load, normal)
     dlt_set_id(daemon.ecuid, ecu);
     EXPECT_EQ(0, dlt_daemon_init_user_information(&daemon, &gateway, 0, 0));
     EXPECT_EQ(DLT_RETURN_OK, strncmp(daemon.ecuid, daemon.user_list[0].ecu, DLT_ID_SIZE));
-    EXPECT_LE(0, dlt_daemon_applications_load(&daemon, (char *)filename, 0));
+    char filename_buf[256] = {0};
+    strncpy(filename_buf, filename, sizeof(filename_buf)-1);
+    filename_buf[sizeof(filename_buf)-1] = '\0';
+    EXPECT_LE(0, dlt_daemon_applications_load(&daemon, filename_buf, 0));
     EXPECT_EQ(0, dlt_daemon_free(&daemon, 0));
 }
 TEST(t_dlt_daemon_applications_load, abnormal)
@@ -690,7 +765,10 @@ TEST(t_dlt_daemon_applications_load, nullpointer)
 
     /* NULL-Pointer */
     EXPECT_GE(-1, dlt_daemon_applications_load(NULL, NULL, 0));
-    EXPECT_GE(-1, dlt_daemon_applications_load(NULL, (char *)filename, 0));
+    char filename_buf[256] = {0};
+    strncpy(filename_buf, filename, sizeof(filename_buf)-1);
+    filename_buf[sizeof(filename_buf)-1] = '\0';
+    EXPECT_GE(-1, dlt_daemon_applications_load(NULL, filename_buf, 0));
     EXPECT_GE(-1, dlt_daemon_applications_load(&daemon, NULL, 0));
 }
 /* End Method: dlt_daemon_common::dlt_daemon_applications_load */
@@ -776,12 +854,13 @@ TEST(t_dlt_daemon_context_add, abnormal)
     dlt_set_id(daemon.ecuid, ecu);
     EXPECT_EQ(0, dlt_daemon_init_user_information(&daemon, &gateway, 0, 0));
     EXPECT_EQ(DLT_RETURN_OK, strncmp(daemon.ecuid, daemon.user_list[0].ecu, DLT_ID_SIZE));
-    DltLogLevelType DLT_LOG_NOT_EXIST = (DltLogLevelType) - 100;
+    /* Log level out of valid range (-1 to 6), should return NULL */
+    int8_t invalid_log_level = 100;
     app = dlt_daemon_application_add(&daemon, apid, 0, desc, fd, ecu, 0);
     daecontext = dlt_daemon_context_add(&daemon,
                                         apid,
                                         ctid,
-                                        DLT_LOG_NOT_EXIST,
+                                        invalid_log_level,
                                         DLT_TRACE_STATUS_DEFAULT,
                                         0,
                                         0,
@@ -795,14 +874,14 @@ TEST(t_dlt_daemon_context_add, abnormal)
     EXPECT_LE(0, dlt_daemon_contexts_clear(&daemon, ecu, 0));
     EXPECT_LE(0, dlt_daemon_applications_clear(&daemon, ecu, 0));
 
-    /* Trace Status dont exists */
-    DltTraceStatusType DLT_TRACE_TYPE_NOT_EXIST = (DltTraceStatusType) - 100;
+    /* Trace Status out of valid range (-1 to 1), should return NULL */
+    int8_t invalid_trace_status = 100;
     app = dlt_daemon_application_add(&daemon, apid, 0, desc, fd, ecu, 0);
     daecontext = dlt_daemon_context_add(&daemon,
                                         apid,
                                         ctid,
                                         DLT_LOG_DEFAULT,
-                                        DLT_TRACE_TYPE_NOT_EXIST,
+                                        invalid_trace_status,
                                         0,
                                         0,
                                         desc,
@@ -1727,6 +1806,297 @@ TEST(t_dlt_daemon_user_send_log_state, nullpointer)
 }
 /* End Method: dlt_daemon_common::dlt_daemon_user_send_log_state */
 
+
+#ifdef DLT_TRACE_LOAD_CTRL_ENABLE
+TEST(t_dlt_daemon_find_preconfigured_trace_load_settings, nullpointer)
+{
+    int num_settings;
+    DltTraceLoadSettings *settings = NULL;
+    DltDaemon daemon;
+
+    EXPECT_EQ(dlt_daemon_find_preconfigured_trace_load_settings(
+                  NULL, "APP1", "CTID", &settings, &num_settings, 0),
+              DLT_RETURN_WRONG_PARAMETER);
+    EXPECT_EQ(dlt_daemon_find_preconfigured_trace_load_settings(
+                  &daemon, NULL, "CTID", &settings, &num_settings, 0),
+              DLT_RETURN_WRONG_PARAMETER);
+}
+
+TEST(t_dlt_daemon_find_preconfigured_trace_load_settings, empty_trace_settings)
+{
+    int num_settings;
+    DltTraceLoadSettings *settings = NULL;
+    DltDaemon daemon;
+    daemon.preconfigured_trace_load_settings = NULL;
+
+    EXPECT_EQ(dlt_daemon_find_preconfigured_trace_load_settings(
+                  &daemon, "APP1", NULL, &settings, &num_settings, 0),
+              DLT_RETURN_OK);
+
+    // test wrong trace load settings count
+    daemon.preconfigured_trace_load_settings = (DltTraceLoadSettings *)malloc(
+        sizeof(DltTraceLoadSettings));
+    daemon.preconfigured_trace_load_settings_count = 0;
+
+    EXPECT_EQ(dlt_daemon_find_preconfigured_trace_load_settings(
+                  &daemon, "APP1", "CTID", &settings, &num_settings, 0),
+              DLT_RETURN_OK);
+
+    free(daemon.preconfigured_trace_load_settings);
+}
+
+TEST(t_dlt_daemon_find_preconfigured_trace_load_settings, app_id_not_found)
+{
+    int num_settings = 42;
+    DltTraceLoadSettings *settings = (DltTraceLoadSettings *)42;
+    DltDaemon daemon;
+
+    // test wrong trace load settings count
+    daemon.preconfigured_trace_load_settings = (DltTraceLoadSettings *)malloc(
+        sizeof(DltTraceLoadSettings));
+    memset(daemon.preconfigured_trace_load_settings, 0,
+           sizeof(DltTraceLoadSettings));
+
+    strncpy(daemon.preconfigured_trace_load_settings[0].apid, "APP2", DLT_ID_SIZE);
+    daemon.preconfigured_trace_load_settings_count = 1;
+
+    EXPECT_EQ(dlt_daemon_find_preconfigured_trace_load_settings(
+                  &daemon, "APP1", NULL, &settings, &num_settings, 0),
+              DLT_RETURN_OK);
+    EXPECT_EQ(num_settings, 0);
+    EXPECT_TRUE(settings == NULL);
+
+    free(daemon.preconfigured_trace_load_settings);
+}
+
+static void setup_trace_load_settings(DltDaemon &daemon)
+{
+    daemon.preconfigured_trace_load_settings_count = 7;
+    daemon.preconfigured_trace_load_settings = (DltTraceLoadSettings *)malloc(
+        daemon.preconfigured_trace_load_settings_count * sizeof(DltTraceLoadSettings));
+    memset(daemon.preconfigured_trace_load_settings, 0,
+           daemon.preconfigured_trace_load_settings_count * sizeof(DltTraceLoadSettings));
+
+    strncpy(daemon.preconfigured_trace_load_settings[0].apid, "APP2", DLT_ID_SIZE);
+    strncpy(daemon.preconfigured_trace_load_settings[0].ctid, "CTID", DLT_ID_SIZE);
+
+    strncpy(daemon.preconfigured_trace_load_settings[1].apid, "APP1", DLT_ID_SIZE);
+    strncpy(daemon.preconfigured_trace_load_settings[1].ctid, "CTID", DLT_ID_SIZE);
+    daemon.preconfigured_trace_load_settings[1].soft_limit = 21;
+    daemon.preconfigured_trace_load_settings[1].hard_limit = 42;
+
+    strncpy(daemon.preconfigured_trace_load_settings[2].apid, "APP1", DLT_ID_SIZE);
+    strncpy(daemon.preconfigured_trace_load_settings[2].ctid, "CT02", DLT_ID_SIZE);
+    daemon.preconfigured_trace_load_settings[2].soft_limit = 11;
+    daemon.preconfigured_trace_load_settings[2].hard_limit = 22;
+
+    strncpy(daemon.preconfigured_trace_load_settings[3].apid, "APP1", DLT_ID_SIZE);
+    daemon.preconfigured_trace_load_settings[3].soft_limit = 44;
+    daemon.preconfigured_trace_load_settings[3].hard_limit = 55;
+
+    strncpy(daemon.preconfigured_trace_load_settings[4].apid, "APP3", DLT_ID_SIZE);
+    strncpy(daemon.preconfigured_trace_load_settings[4].ctid, "CT03", DLT_ID_SIZE);
+    daemon.preconfigured_trace_load_settings[4].soft_limit = 111;
+    daemon.preconfigured_trace_load_settings[4].hard_limit = 222;
+
+    strncpy(daemon.preconfigured_trace_load_settings[5].apid, "APP3", DLT_ID_SIZE);
+    strncpy(daemon.preconfigured_trace_load_settings[5].ctid, "CT01", DLT_ID_SIZE);
+    daemon.preconfigured_trace_load_settings[5].soft_limit = 333;
+    daemon.preconfigured_trace_load_settings[5].hard_limit = 444;
+
+    strncpy(daemon.preconfigured_trace_load_settings[6].apid, "APP1", DLT_ID_SIZE);
+    strncpy(daemon.preconfigured_trace_load_settings[6].ctid, "CT03", DLT_ID_SIZE);
+    daemon.preconfigured_trace_load_settings[6].soft_limit = 555;
+    daemon.preconfigured_trace_load_settings[6].hard_limit = 666;
+
+    qsort(daemon.preconfigured_trace_load_settings, daemon.preconfigured_trace_load_settings_count,
+          sizeof(DltTraceLoadSettings), dlt_daemon_compare_trace_load_settings);
+}
+
+TEST(t_dlt_daemon_find_preconfigured_trace_load_settings, search_with_context)
+{
+    int num_settings = 42;
+    DltTraceLoadSettings *settings = NULL;
+    DltDaemon daemon;
+
+    setup_trace_load_settings(daemon);
+
+    EXPECT_EQ(dlt_daemon_find_preconfigured_trace_load_settings(
+                  &daemon, "APP1", "CTID", &settings, &num_settings, 0),
+              DLT_RETURN_OK);
+    EXPECT_EQ(num_settings, 1);
+    EXPECT_EQ(memcmp(settings, &daemon.preconfigured_trace_load_settings[3],
+                     sizeof(DltTraceLoadSettings)),
+              0);
+
+    free(settings);
+    free(daemon.preconfigured_trace_load_settings);
+}
+
+TEST(t_dlt_daemon_find_preconfigured_trace_load_settings, search_with_app_id)
+{
+    int num_settings = 42;
+    DltTraceLoadSettings *settings = NULL;
+    DltDaemon daemon;
+
+    setup_trace_load_settings(daemon);
+
+    EXPECT_EQ(dlt_daemon_find_preconfigured_trace_load_settings(
+                  &daemon, "APP1", NULL, &settings, &num_settings, 0),
+              DLT_RETURN_OK);
+    EXPECT_EQ(num_settings, 4);
+    for (int i = 0; i < num_settings; i++) {
+        EXPECT_EQ(memcmp(&settings[i],
+                         &daemon.preconfigured_trace_load_settings[i],
+                         sizeof(DltTraceLoadSettings)),0);
+    }
+
+    free(settings);
+    free(daemon.preconfigured_trace_load_settings);
+}
+
+TEST(t_dlt_daemon_application_add, trace_load_settings_not_found)
+{
+    DltDaemon daemon;
+    DltGateway gateway;
+    const char *apid_const = "TEST";
+    pid_t pid = 0;
+    const char *desc_const = "HELLO_TEST";
+    DltDaemonApplication *app = NULL;
+    char ecu[] = "ECU1";
+    int fd = 15;
+
+    EXPECT_EQ(0, dlt_daemon_init(&daemon, DLT_DAEMON_RINGBUFFER_MIN_SIZE,
+                                 DLT_DAEMON_RINGBUFFER_MAX_SIZE,
+                                 DLT_DAEMON_RINGBUFFER_STEP_SIZE,
+                                 DLT_RUNTIME_DEFAULT_DIRECTORY, DLT_LOG_INFO,
+                                 DLT_TRACE_STATUS_OFF, 0, 0));
+    dlt_set_id(daemon.ecuid, ecu);
+    EXPECT_EQ(0, dlt_daemon_init_user_information(&daemon, &gateway, 0, 0));
+    EXPECT_EQ(DLT_RETURN_OK,
+              strncmp(daemon.ecuid, daemon.user_list[0].ecu, DLT_ID_SIZE));
+    char apid[DLT_ID_SIZE+1] = {0};
+    char desc[32] = {0};
+    strncpy(apid, apid_const, DLT_ID_SIZE);
+    apid[DLT_ID_SIZE] = '\0';
+    strncpy(desc, desc_const, sizeof(desc)-1);
+    desc[sizeof(desc)-1] = '\0';
+    app = dlt_daemon_application_add(&daemon, apid, pid, desc,
+                                     fd, ecu, 0);
+    EXPECT_FALSE(app->trace_load_settings == NULL);
+    EXPECT_EQ(app->trace_load_settings_count, 1);
+    EXPECT_EQ(app->trace_load_settings[0].soft_limit,
+              DLT_TRACE_LOAD_DAEMON_SOFT_LIMIT_DEFAULT);
+    EXPECT_EQ(app->trace_load_settings[0].hard_limit,
+              DLT_TRACE_LOAD_DAEMON_HARD_LIMIT_DEFAULT);
+    EXPECT_STREQ(app->trace_load_settings[0].apid, apid);
+    EXPECT_TRUE(app->trace_load_settings[0].ctid == NULL ||
+                strlen(app->trace_load_settings[0].ctid) == 0);
+
+    EXPECT_LE(0, dlt_daemon_application_del(&daemon, app, ecu, 0));
+    EXPECT_LE(0, dlt_daemon_applications_clear(&daemon, ecu, 0));
+
+    dlt_daemon_application_del(&daemon, app, ecu, 0);
+    EXPECT_TRUE(app->trace_load_settings == NULL);
+    EXPECT_EQ(0, dlt_daemon_free(&daemon, 0));
+}
+
+TEST(t_dlt_daemon_application_add, trace_load_settings_configured)
+{
+    DltDaemon daemon;
+    DltGateway gateway;
+    const char *apid_const = "APP1";
+    pid_t pid = 0;
+    const char *desc_const = "HELLO_TEST";
+    DltDaemonApplication *app = NULL;
+    char ecu[] = "ECU1";
+    int fd = 15;
+
+    EXPECT_EQ(0, dlt_daemon_init(&daemon, DLT_DAEMON_RINGBUFFER_MIN_SIZE,
+                                 DLT_DAEMON_RINGBUFFER_MAX_SIZE,
+                                 DLT_DAEMON_RINGBUFFER_STEP_SIZE,
+                                 DLT_RUNTIME_DEFAULT_DIRECTORY, DLT_LOG_INFO,
+                                 DLT_TRACE_STATUS_OFF, 0, 0));
+
+    // must be done after daemon init, else data is overwritten
+    setup_trace_load_settings(daemon);
+
+    dlt_set_id(daemon.ecuid, ecu);
+    EXPECT_EQ(0, dlt_daemon_init_user_information(&daemon, &gateway, 0, 0));
+    EXPECT_EQ(DLT_RETURN_OK,
+              strncmp(daemon.ecuid, daemon.user_list[0].ecu, DLT_ID_SIZE));
+    char apid[DLT_ID_SIZE+1] = {0};
+    char desc[32] = {0};
+    strncpy(apid, apid_const, DLT_ID_SIZE);
+    apid[DLT_ID_SIZE] = '\0';
+    strncpy(desc, desc_const, sizeof(desc)-1);
+    desc[sizeof(desc)-1] = '\0';
+    app = dlt_daemon_application_add(&daemon, apid, pid, desc,
+                                     fd, ecu, 0);
+    EXPECT_FALSE(app->trace_load_settings == NULL);
+    EXPECT_EQ(app->trace_load_settings_count, 4);
+
+    for (uint32_t i = 0; i < app->trace_load_settings_count; i++) {
+        EXPECT_EQ(memcmp(&app->trace_load_settings[i],
+                         &daemon.preconfigured_trace_load_settings[i],
+                         sizeof(DltTraceLoadSettings)), 0);
+    }
+
+    EXPECT_LE(0, dlt_daemon_application_del(&daemon, app, ecu, 0));
+    EXPECT_LE(0, dlt_daemon_applications_clear(&daemon, ecu, 0));
+
+    dlt_daemon_application_del(&daemon, app, ecu, 0);
+    EXPECT_TRUE(app->trace_load_settings == NULL);
+    EXPECT_EQ(0, dlt_daemon_free(&daemon, 0));
+}
+
+TEST(t_dlt_daemon_user_send_trace_load_config, normal)
+{
+    DltDaemon daemon;
+    DltGateway gateway;
+    const char *apid_const = "APP1";
+    pid_t pid = 0;
+    const char *desc_const = "HELLO_TEST";
+    DltDaemonApplication *app = NULL;
+    char ecu[] = "ECU1";
+    int fd = 15;
+
+    EXPECT_EQ(0, dlt_daemon_init(&daemon, DLT_DAEMON_RINGBUFFER_MIN_SIZE,
+                                 DLT_DAEMON_RINGBUFFER_MAX_SIZE,
+                                 DLT_DAEMON_RINGBUFFER_STEP_SIZE,
+                                 DLT_RUNTIME_DEFAULT_DIRECTORY, DLT_LOG_INFO,
+                                 DLT_TRACE_STATUS_OFF, 0, 0));
+
+    dlt_set_id(daemon.ecuid, ecu);
+    EXPECT_EQ(0, dlt_daemon_init_user_information(&daemon, &gateway, 0, 0));
+    EXPECT_EQ(DLT_RETURN_OK,
+              strncmp(daemon.ecuid, daemon.user_list[0].ecu, DLT_ID_SIZE));
+    char apid[DLT_ID_SIZE+1] = {0};
+    char desc[32] = {0};
+    strncpy(apid, apid_const, DLT_ID_SIZE);
+    apid[DLT_ID_SIZE] = '\0';
+    strncpy(desc, desc_const, sizeof(desc)-1);
+    desc[sizeof(desc)-1] = '\0';
+    app = dlt_daemon_application_add(&daemon, apid, pid, desc,
+                                     fd, ecu, 0);
+    dlt_daemon_user_send_trace_load_config(&daemon, app, 0);
+    dlt_daemon_application_del(&daemon, app, ecu, 0);
+
+    setup_trace_load_settings(daemon);
+
+    strncpy(apid, apid_const, DLT_ID_SIZE);
+    apid[DLT_ID_SIZE] = '\0';
+    strncpy(desc, desc_const, sizeof(desc)-1);
+    desc[sizeof(desc)-1] = '\0';
+    app = dlt_daemon_application_add(&daemon, apid, pid, desc,
+                                     fd, ecu, 0);
+    dlt_daemon_user_send_trace_load_config(&daemon, app, 0);
+    dlt_daemon_application_del(&daemon, app, ecu, 0);
+    EXPECT_EQ(0, dlt_daemon_free(&daemon, 0));
+}
+
+#endif
+
 /*##############################################################################################################################*/
 /*##############################################################################################################################*/
 /*##############################################################################################################################*/
